..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Summary
-------

-  Algorithm analysis is an implementation-independent way of measuring
   an algorithm.

-  Big O notation allows algorithms to be classified by their dominant
   process with respect to the size of the problem.
